==> morsel-editor-2.0.6.tgz: package/README.md <==
# Morsel
Morsel is a very simple syntax highlighter and code editor, written in JavaScript.
To start, open the command line in your project and write:
```
npm install morsel-editor
```
This will install Morsel in your project. To use it in your project, type the following in your index.html:
``` html
<script src="./node_modules/morsel-editor/morsel.js"></script>
```
or
``` html
<script src="./node_modules/morsel-editor/morsel.min.js"></script>
```
If you're using JSX or TSX, you can import it using the `import` statement:
``` js
import "./node_modules/morsel-editor/morsel.js"
```
or
``` js
import "./node_modules/morsel-editor/morsel.min.js"
```
To actually use it, create a div:
``` html
<div id="myEditor"></div>
```
Then, in your JavaScript, write:
``` js
morsel.editor.init(document.getElementById("myEditor"), "html", "&lt;p&gt;My first editor!&lt;/p&gt;", morsel.defaultTheme);
```
Congratulations! You just made your first editor!
To get some help, run: 
```
cd node_modules/morsel-editor && npm run help
```
If you don't have Node.js, you can [click me](https://drive.google.com/file/d/16yrGhFhnMBp8cnKL486W1oxyeKKXtyoj/view?usp=drive_link) and click download on the page that shows up. To use it, in this case, write:
``` html
<script src="morsel.min.js"></script>
```
If it is in a folder in the same directory, write the folder name between ./ and /:
``` html
<script src="./foldername/morsel.min.js"></script>
```
If it is at the root of the drive, add a slash:
``` html
<script src="/morsel.min.js"></script>
```
If it is in a folder at the root of the drive, write the folder name between slashes:
``` html
<script src="/foldername/morsel.min.js"></script>
```

==> morsel-editor-2.0.9.tgz: package/README.md <==
# Morsel
Morsel is a very simple syntax highlighter and code editor, written in JavaScript.
To start, open the command line in your project and write:
```
npm install morsel-editor
```
This will install Morsel in your project. To use it in your project, type the following in your index.html:
``` html
<script src="./node_modules/morsel-editor/morsel.js"></script>
```
or
``` html
<script src="./node_modules/morsel-editor/morsel.min.js"></script>
```
If you're using JSX or TSX, you can import it using the `import` statement:
``` js
import "./node_modules/morsel-editor/morsel.js"
```
or
``` js
import "./node_modules/morsel-editor/morsel.min.js"
```
To actually use it, create a div:
``` html
<div id="myEditor"></div>
```
Then, in your JavaScript, write:
``` js
morsel.editor.init(document.getElementById("myEditor"), "html", "&lt;p&gt;My first editor!&lt;/p&gt;", morsel.defaultTheme);
```
Congratulations! You just made your first editor!
To get some help, run: 
```
cd node_modules/morsel-editor && npm run help
```
If you don't have Node.js, you can [click me](https://drive.google.com/file/d/16yrGhFhnMBp8cnKL486W1oxyeKKXtyoj/view?usp=drive_link) and click download on the page that shows up. To use it, in this case, write:
``` html
<script src="morsel.min.js"></script>
```
If it is in a folder in the same directory, write the folder name between ./ and /:
``` html
<script src="./*foldername*/morsel.min.js"></script>
```
If it is at the root of the drive, add a slash:
``` html
<script src="/morsel.min.js"></script>
```
If it is in a folder at the root of the drive, write the folder name between slashes:
``` html
<script src="/*foldername*/morsel.min.js"></script>
```
To just syntax highlight an element, make a pre element:
``` html
<pre id="myPre">&lt;p&gt;My first code!&lt;/p&gt;</pre>
```
Then write this in your scripts:
``` js
morsel.syntaxHighlight(document.getElementById("myPre"), "html");
```
